| get_program_trials | R Documentation |
This internal function retrieves the list of trials for the currently active breeding program
and crop combination. The crop and program must be set using set_crop and
set_program prior to calling this function.
get_program_trials()
A data frame containing information on trials for the active breeding program.
Khaled Al-Shamaa, k.el-shamaa@cgiar.org
login_bms, set_crop, set_program, list_trials
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.