powered by
Retrieves a list of locations associated with the current active crop, as configured in the internal state object using the set_crop function.
set_crop
list_locations()
A data frame containing information about locations relevant to the current crop.
Khaled Al-Shamaa, [email protected]
login_bms, set_crop for related crop operations.
login_bms