| list_studies | R Documentation |
Retrieves a list of studies (and associated locations) for the currently active trial, as configured
using the set_trial function.
list_studies()
A data frame containing study names and associated location names. If no studies are available, an error is thrown.
This function must be called after a trial has been set using set_trial.
Khaled Al-Shamaa, k.el-shamaa@cgiar.org
login_bms, set_crop, set_program, set_trial for related operations on crops, programs, and trials.
if (interactive()) {
set_qbms_config("https://bms.icarda.org/ibpworkbench")
login_bms() # Log in to the server
set_crop("wheat") # Set crop
set_program("Wheat International Nurseries") # Set breeding program
set_trial("IDYT39") # Set trial
list_studies() # List studies
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.